# mypy-boto3-elasticbeanstalk<a id="mypy-boto3-elasticbeanstalk"></a>

[![PyPI - mypy-boto3-elasticbeanstalk](https://img.shields.io/pypi/v/mypy-boto3-elasticbeanstalk.svg?color=blue)](https://pypi.org/project/mypy-boto3-elasticbeanstalk)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-elasticbeanstalk.svg?color=blue)](https://pypi.org/project/mypy-boto3-elasticbeanstalk)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-elasticbeanstalk?color=blue)](https://pypistats.org/packages/mypy-boto3-elasticbeanstalk)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.ElasticBeanstalk 1.17.87](https://boto3.amazonaws.com/v1/documentation/api/1.17.87/reference/services/elasticbeanstalk.html#ElasticBeanstalk)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.14.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-elasticbeanstalk docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticbeanstalk/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-elasticbeanstalk](#mypy-boto3-elasticbeanstalk)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

## How to install<a id="how-to-install"></a>

Install `boto3-stubs` for `ElasticBeanstalk` service.

```bash
python -m pip install boto3-stubs[elasticbeanstalk]
```

## Usage<a id="usage"></a>

### VSCode<a id="vscode"></a>

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[elasticbeanstalk]` in your environment:
  `python -m pip install 'boto3-stubs[elasticbeanstalk]'`

Both type checking and auto-complete should work for `ElasticBeanstalk`
service. No explicit type annotations required, write your `boto3` code as
usual.

### PyCharm<a id="pycharm"></a>

- Install `boto-stubs[elasticbeanstalk]` in your environment:
  `python -m pip install 'boto3-stubs[elasticbeanstalk]'`

Both type checking and auto-complete should work for `ElasticBeanstalk`
service. No explicit type annotations required, write your `boto3` code as
usual. Auto-complete can be slow on big projects or if you have a lot of
installed `boto3-stubs` submodules.

### Other IDEs<a id="other-ides"></a>

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

### mypy<a id="mypy"></a>

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[elasticbeanstalk]` in your environment:
  `python -m pip install 'boto3-stubs[elasticbeanstalk]'`
- Run `mypy` as usual

Type checking should work for `ElasticBeanstalk` service. No explicit type
annotations required, write your `boto3` code as usual.

### pyright<a id="pyright"></a>

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[elasticbeanstalk]` in your environment:
  `python -m pip install 'boto3-stubs[elasticbeanstalk]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `ElasticBeanstalk` service. No explicit type
annotations required, write your `boto3` code as usual.

## Explicit type annotations<a id="explicit-type-annotations"></a>

### Client annotations<a id="client-annotations"></a>

`ElasticBeanstalkClient` provides annotations for
`boto3.client("elasticbeanstalk")`.

```python
import boto3

from mypy_boto3_elasticbeanstalk import ElasticBeanstalkClient

client: ElasticBeanstalkClient = boto3.client("elasticbeanstalk")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: ElasticBeanstalkClient = session.client("elasticbeanstalk")
```

### Paginators annotations<a id="paginators-annotations"></a>

`mypy_boto3_elasticbeanstalk.paginator` module contains type annotations for
all paginators.

```python
from mypy_boto3_elasticbeanstalk import ElasticBeanstalkClient
from mypy_boto3_elasticbeanstalk.paginator import (
    DescribeApplicationVersionsPaginator,
    DescribeEnvironmentManagedActionHistoryPaginator,
    DescribeEnvironmentsPaginator,
    DescribeEventsPaginator,
    ListPlatformVersionsPaginator,
)

client: ElasticBeanstalkClient = boto3.client("elasticbeanstalk")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_application_versions_paginator: DescribeApplicationVersionsPaginator = client.get_paginator("describe_application_versions")
describe_environment_managed_action_history_paginator: DescribeEnvironmentManagedActionHistoryPaginator = client.get_paginator("describe_environment_managed_action_history")
describe_environments_paginator: DescribeEnvironmentsPaginator = client.get_paginator("describe_environments")
describe_events_paginator: DescribeEventsPaginator = client.get_paginator("describe_events")
list_platform_versions_paginator: ListPlatformVersionsPaginator = client.get_paginator("list_platform_versions")
```

### Waiters annotations<a id="waiters-annotations"></a>

`mypy_boto3_elasticbeanstalk.waiter` module contains type annotations for all
waiters.

```python
from mypy_boto3_elasticbeanstalk import ElasticBeanstalkClient
from mypy_boto3_elasticbeanstalk.waiter import (
    EnvironmentExistsWaiter,
    EnvironmentTerminatedWaiter,
    EnvironmentUpdatedWaiter,
)

client: ElasticBeanstalkClient = boto3.client("elasticbeanstalk")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
environment_exists_waiter: EnvironmentExistsWaiter = client.get_waiter("environment_exists")
environment_terminated_waiter: EnvironmentTerminatedWaiter = client.get_waiter("environment_terminated")
environment_updated_waiter: EnvironmentUpdatedWaiter = client.get_waiter("environment_updated")
```

### Literals<a id="literals"></a>

`mypy_boto3_elasticbeanstalk.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from mypy_boto3_elasticbeanstalk.literals import (
    ActionHistoryStatusType,
    ActionStatusType,
    ActionTypeType,
    ApplicationVersionStatusType,
    ComputeTypeType,
    ConfigurationDeploymentStatusType,
    ConfigurationOptionValueTypeType,
    DescribeApplicationVersionsPaginatorName,
    DescribeEnvironmentManagedActionHistoryPaginatorName,
    DescribeEnvironmentsPaginatorName,
    DescribeEventsPaginatorName,
    EnvironmentExistsWaiterName,
    EnvironmentHealthAttributeType,
    EnvironmentHealthStatusType,
    EnvironmentHealthType,
    EnvironmentInfoTypeType,
    EnvironmentStatusType,
    EnvironmentTerminatedWaiterName,
    EnvironmentUpdatedWaiterName,
    EventSeverityType,
    FailureTypeType,
    InstancesHealthAttributeType,
    ListPlatformVersionsPaginatorName,
    PlatformStatusType,
    SourceRepositoryType,
    SourceTypeType,
    ValidationSeverityType,
)

def check_value(value: ActionHistoryStatusType) -> bool:
    ...
```

### Typed dictionaries<a id="typed-dictionaries"></a>

`mypy_boto3_elasticbeanstalk.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_elasticbeanstalk.type_defs import (
    ApplicationDescriptionMessageTypeDef,
    ApplicationDescriptionTypeDef,
    ApplicationDescriptionsMessageTypeDef,
    ApplicationMetricsTypeDef,
    ApplicationResourceLifecycleConfigTypeDef,
    ApplicationResourceLifecycleDescriptionMessageTypeDef,
    ApplicationVersionDescriptionMessageTypeDef,
    ApplicationVersionDescriptionTypeDef,
    ApplicationVersionDescriptionsMessageTypeDef,
    ApplicationVersionLifecycleConfigTypeDef,
    ApplyEnvironmentManagedActionResultTypeDef,
    AutoScalingGroupTypeDef,
    BuildConfigurationTypeDef,
    BuilderTypeDef,
    CPUUtilizationTypeDef,
    CheckDNSAvailabilityResultMessageTypeDef,
    ConfigurationOptionDescriptionTypeDef,
    ConfigurationOptionSettingTypeDef,
    ConfigurationOptionsDescriptionTypeDef,
    ConfigurationSettingsDescriptionTypeDef,
    ConfigurationSettingsDescriptionsTypeDef,
    ConfigurationSettingsValidationMessagesTypeDef,
    CreatePlatformVersionResultTypeDef,
    CreateStorageLocationResultMessageTypeDef,
    CustomAmiTypeDef,
    DeletePlatformVersionResultTypeDef,
    DeploymentTypeDef,
    DescribeAccountAttributesResultTypeDef,
    DescribeEnvironmentHealthResultTypeDef,
    DescribeEnvironmentManagedActionHistoryResultTypeDef,
    DescribeEnvironmentManagedActionsResultTypeDef,
    DescribeInstancesHealthResultTypeDef,
    DescribePlatformVersionResultTypeDef,
    EnvironmentDescriptionTypeDef,
    EnvironmentDescriptionsMessageTypeDef,
    EnvironmentInfoDescriptionTypeDef,
    EnvironmentLinkTypeDef,
    EnvironmentResourceDescriptionTypeDef,
    EnvironmentResourceDescriptionsMessageTypeDef,
    EnvironmentResourcesDescriptionTypeDef,
    EnvironmentTierTypeDef,
    EventDescriptionTypeDef,
    EventDescriptionsMessageTypeDef,
    InstanceHealthSummaryTypeDef,
    InstanceTypeDef,
    LatencyTypeDef,
    LaunchConfigurationTypeDef,
    LaunchTemplateTypeDef,
    ListAvailableSolutionStacksResultMessageTypeDef,
    ListPlatformBranchesResultTypeDef,
    ListPlatformVersionsResultTypeDef,
    ListenerTypeDef,
    LoadBalancerDescriptionTypeDef,
    LoadBalancerTypeDef,
    ManagedActionHistoryItemTypeDef,
    ManagedActionTypeDef,
    MaxAgeRuleTypeDef,
    MaxCountRuleTypeDef,
    OptionRestrictionRegexTypeDef,
    OptionSpecificationTypeDef,
    PaginatorConfigTypeDef,
    PlatformBranchSummaryTypeDef,
    PlatformDescriptionTypeDef,
    PlatformFilterTypeDef,
    PlatformFrameworkTypeDef,
    PlatformProgrammingLanguageTypeDef,
    PlatformSummaryTypeDef,
    QueueTypeDef,
    ResourceQuotaTypeDef,
    ResourceQuotasTypeDef,
    ResourceTagsDescriptionMessageTypeDef,
    RetrieveEnvironmentInfoResultMessageTypeDef,
    S3LocationTypeDef,
    SearchFilterTypeDef,
    SingleInstanceHealthTypeDef,
    SolutionStackDescriptionTypeDef,
    SourceBuildInformationTypeDef,
    SourceConfigurationTypeDef,
    StatusCodesTypeDef,
    SystemStatusTypeDef,
    TagTypeDef,
    TriggerTypeDef,
    ValidationMessageTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> ApplicationDescriptionMessageTypeDef:
    return {
      ...
    }
```

## Versioning<a id="versioning"></a>

`mypy-boto3-elasticbeanstalk` version is the same as related `boto3` version
and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation<a id="documentation"></a>

All type annotations can be found in
[mypy-boto3-elasticbeanstalk docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elasticbeanstalk/)

## Support and contributing<a id="support-and-contributing"></a>

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
